tox-pyenv
=========

| |latest| |Circle CI|

`tox <https://tox.readthedocs.org/en/latest/>`__ plugin that uses
``pyenv which`` to `find python
executables <https://testrun.org/tox/latest/plugins.html#tox.hookspecs.tox_get_python_executable>`__

.. |latest| image:: https://img.shields.io/pypi/v/tox-pyenv.svg
   :target: https://pypi.python.org/pypi/tox-pyenv
.. |Circle CI| image:: https://circleci.com/gh/samstav/tox-pyenv/tree/master.svg?style=shield
   :target: https://circleci.com/gh/samstav/tox-pyenv/tree/master
